@@ -291,13 +291,15 @@ class DSLibrary(object):
 
     def get_filesystem_connection(self, resource_name: str, for_write: bool=False, **kwargs):
         """
-        Returns a FileSystem class for a given external filesystem, like s3, abs, gcs, etc..
+        Returns a FileSystem class for a given external filesystem, like s3, abs, gcs, etc..  See engine_intf.FileSystem,
+        which is a simplified version of fsspec.AbstractFileSystem.
 
         :param resource_name:   Which filesystem to access.  This can be the name of an input or output resource, or a
                                 URI providing connection details.
         :param for_write:       True to enable write operations.
         :param kwargs:      Additional arguments, including...
                 bucket = named bucket within the filesystem provider/engine.
+                read_only = restricts to read operations
         """
         return self._get_system_connection("filesystem", resource_name, for_write, **kwargs)
 
