@@ -174,11 +174,20 @@ class DSLibraryViaMMLibrary(DSLibrary):
         params = {}
         if database:
             if "database" in sig.parameters:
+                # TODO this parameter is deprecated--let's not create open-ended connections that can access any db
                 params["database"] = database
             else:
                 raise DSLibraryException("The 'database' parameter is not supported by this implementation of get_db_connection()")
         return method(resource_name, **params)
 
+    def _get_system_connection(self, system_type, resource_name: str, for_write: bool=False, **kwargs):
+        """
+        All types of connection can be accessed through mmlibrary.get_db_connection() (some day it will change to
+        'get_connection()').
+        """
+        method = self._find_method("get_db_connection")
+        return method(resource_name, read_only=not for_write)
+
     def install_packages(self, packages: list, verbose: bool=False):
         method = self._find_method("install_packages")
         sig = inspect.signature(method)
