@@ -7,7 +7,7 @@ import tempfile
 import typing
 import urllib.request
 
-from dslibrary.engine_intf import FileSystemLocal, FileSystemReadOnly
+from dslibrary.engine_intf import FileSystemLocal, FileSystemReadOnly, S3Connection
 
 try:
     import fsspec
@@ -135,6 +135,9 @@ def connect_to_filesystem(uri: str, for_write: bool=False, **kwargs):
             raise ValueError(f"Invalid URI for external filesystem: {uri}")
         if not fsspec:
             raise ImportWarning(f"fsspec not installed, can't open filesystem: {uri}")
+        if protocol == "s3":
+            # fsspec does not support streaming upload or 'read_only' mode, so we have our own implementation
+            return S3Connection(bucket=bucket, **kwargs)
         fs = fsspec.filesystem(protocol, bucket=bucket, **kwargs)
     if not for_write:
         return FileSystemReadOnly(fs)
