@@ -294,3 +294,22 @@ class TestFront(unittest.TestCase):
                 return FS()
         df = MyInst().load_dataframe("path", filesystem="fs", format="csv")
         assert list(df.x) == [1, 2, 3]
+
+    def test_rw_run_data(self):
+        writes = {}
+        class MyInst(DSLibrary):
+            def open_run_data(self, filename: str, mode: str='rb'):
+                if mode == 'rb':
+                    v = writes[filename].getvalue()
+                    return io.BytesIO(v)
+                wr = io.BytesIO()
+                writes[filename] = wr
+                wr.close = lambda: None
+                return wr
+        dsl = MyInst()
+        df = pandas.DataFrame({"x": [1, 2]})
+        dsl.write_run_data("x.csv", df)
+        self.assertEqual(writes["x.csv"].getvalue(), b'x\n1\n2\n')
+        df2 = dsl.load_dataframe("x.csv", run_data=True)
+        self.assertEqual(list(df2.x), list(df.x))
+        self.assertEqual(dsl.read_run_data("x.csv"), b'x\n1\n2\n')
